// vim: set tabstop=4 shiftwidth=4 noexpandtab:
/*
A KIPI plugin to generate HTML image galleries
Copyright 2006 by Aurelien Gateau <aurelien dot gateau at free.fr>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA.

*/
// Self
#include "listthemeparameter.h"

// TQt
#include <tqcombobox.h>

// KDE
#include <tdeconfigbase.h>

namespace KIPIHTMLExport {

static const char* ITEM_VALUE_KEY = "Value_";
static const char* ITEM_CAPTION_KEY = "Caption_";

struct ListThemeParameter::Private {
	TQStringList mOrderedValueList;
	TQMap<TQString, TQString> mContentMap;
};

ListThemeParameter::ListThemeParameter() {
	d = new Private;
}

ListThemeParameter::~ListThemeParameter() {
	delete d;
}

void ListThemeParameter::init(const TQCString& internalName, const TDEConfigBase* configFile) {
	AbstractThemeParameter::init(internalName, configFile);

	for (int pos=0;; ++pos) {
		TQString valueKey = TQString("%1%2").arg(ITEM_VALUE_KEY).arg(pos);
		TQString captionKey = TQString("%1%2").arg(ITEM_CAPTION_KEY).arg(pos);
		if (!configFile->hasKey(valueKey) || !configFile->hasKey(captionKey)) {
			break;
		}

		TQString value = configFile->readEntry(valueKey);
		TQString caption = configFile->readEntry(captionKey);

		d->mOrderedValueList << value;
		d->mContentMap[value] = caption;
	}
}

TQWidget* ListThemeParameter::createWidget(TQWidget* parent, const TQString& widgetDefaultValue) const {
	TQComboBox* comboBox = new TQComboBox(parent);

	TQStringList::ConstIterator
		it = d->mOrderedValueList.begin(),
		end = d->mOrderedValueList.end();
	for (;it!=end; ++it) {
		TQString value = *it;
		TQString caption = d->mContentMap[value];
		comboBox->insertItem(caption);
		if (value == widgetDefaultValue) {
			comboBox->setCurrentItem(comboBox->count() - 1);
		}
	}

	return comboBox;
}

TQString ListThemeParameter::valueFromWidget(TQWidget* widget) const {
	Q_ASSERT(widget);
	TQComboBox* comboBox = static_cast<TQComboBox*>(widget);
	return d->mOrderedValueList[comboBox->currentItem()];
}

} // namespace

